Package: GREENeR
Type: Package
Title: Geospatial Regression Equation for European Nutrient Losses
        (GREEN)
Version: 1.0.2
Authors@R: c(person("A.", "Udias", role = "aut",
                     email = "angeludias@gmail.com"),
              person("B.", "Grizzetti", role = "aut", 
                     email = "bruna.grizzetti@jrc.it"), 
              person("O.", "Vigiak", role = "aut", 
                     email = "Olga.VIGIAK@ec.europa.eu"),
              person("J.", "Gomez", role = "aut", 
                     email = "javier.gomez@urjc.es"),
              person("C.", "Alfaro", role = c("aut", "cre"),
                     email = "c.alfarog@gmail.com"),
              person("A.", "Aloe", role = "aut", 
                     email = "alberto.aloe@jrc.it"))
Author: A. Udias [aut],
  B. Grizzetti [aut],
  O. Vigiak [aut],
  J. Gomez [aut],
  C. Alfaro [aut, cre],
  A. Aloe [aut]
Maintainer: C. Alfaro <c.alfarog@gmail.com>
Description: Tools and methods to apply the model Geospatial Regression Equation
    for European Nutrient losses (GREEN); 
    Grizzetti et al. (2005) <doi:10.1016/j.jhydrol.2004.07.036>; 
    Grizzetti et al. (2008);
    Grizzetti et al. (2012) <doi:10.1111/j.1365-2486.2011.02576.x>; 
    Grizzetti et al. (2021) <doi:10.1016/j.gloenvcha.2021.102281>. 
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: FME (>= 1.3.6.1), data.table (>= 1.13.6), reshape2 (>= 1.4.4),
        ggplot2 (>= 3.3.5), graphics (>= 3.6.1), sf (>= 1.0-2), dplyr
        (>= 1.0.7), magrittr (>= 2.0.1), tmap (>= 4.3), gridExtra (>=
        2.3), classInt (>= 0.4-3), grDevices (>= 3.5), networkD3 (>=
        0.4), parallelly (>= 1.30.0)
Depends: R (>= 4.1)
RoxygenNote: 7.3.3
URL: https://github.com/calfarog/GREENeR,
        https://calfarog.github.io/GREENeR/
BugReports: https://github.com/calfarog/GREENeR/issues
Suggests: knitr, rmarkdown, codetools
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-22 12:19:27 UTC; cesar.alfaro
Repository: CRAN
Date/Publication: 2026-04-22 12:50:09 UTC
Built: R 4.5.2; ; 2026-04-22 14:44:05 UTC; unix
