# Generated by roxygen2: do not edit by hand

export(LakeRetent_plot)
export(N4_sankey)
export(calib_boxplot)
export(calib_dot)
export(calib_green)
export(compare_calib)
export(gof)
export(green_shares)
export(input_Tserie)
export(input_Tserie_area)
export(input_maps)
export(input_plot)
export(nutrient_maps)
export(nutrient_tserie)
export(nutrient_tserie_darea)
export(read_NSdata)
export(read_geometry)
export(references_plot)
export(region_nut_balance)
export(scatter_plot)
export(select_params)
export(shreve)
export(simobs_annual_plot)
import(dplyr)
import(magrittr)
importFrom(classInt,classIntervals)
importFrom(data.table,":=")
importFrom(data.table,as.data.table)
importFrom(data.table,setkey)
importFrom(dplyr,across)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,everything)
importFrom(dplyr,group_by)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylim)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(gridExtra,grid.arrange)
importFrom(magrittr,"%>%")
importFrom(networkD3,JS)
importFrom(networkD3,sankeyNetwork)
importFrom(parallel,clusterEvalQ)
importFrom(parallel,clusterExport)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,parSapply)
importFrom(parallel,stopCluster)
importFrom(parallelly,availableCores)
importFrom(reshape2,dcast)
importFrom(reshape2,melt)
importFrom(sf,st_area)
importFrom(sf,st_read)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,coefficients)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,lm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(tmap,tm_fill)
importFrom(tmap,tm_layout)
importFrom(tmap,tm_scalebar)
importFrom(tmap,tm_shape)
importFrom(tmap,tmap_arrange)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
