#' @title Catch data TN
#' @description Defines the topological sequence of catchments for nitrogen.
#' @format A data frame with 5 variables:
#' \describe{
#'   \item{\code{HydroID}}{integer positive. Unique catchment identifier.}
#'   \item{\code{To_catch}}{integer. Unique identifier of the catchment to which
#'   the catchment goes. Note that for the outlet To_catch== -1.}
#'   \item{\code{Shreve}}{integer. this indicates the Shreve order of the
#'   topological sequence in the stream network.}
#'   \item{\code{LakeFrRet}}{fraction, 0-1. Lake retention fraction.}
#'   \item{\code{NrmLengthKm}}{double. Normalized length of catchment reach.}
#'}
"catch_data_TN"
