% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgreen.R
\name{append_empty_cols}
\alias{append_empty_cols}
\title{Append empty columns}
\usage{
append_empty_cols(df)
}
\arguments{
\item{df}{data frame. A data frame to add two new columns, Fix and Soil}
}
\value{
One object, a data frame.
}
\description{
This function add empty values to the data frame.
}
\keyword{internal}
